@@ -137,13 +137,13 @@ class Gsof(BaseProtocol):
                 raise e
 
             except socket.timeout:
-                self.close()
+                await self.close()
                 self.sock = self.create_socket(None)
                 self.on_blocking()
                 raise socket.timeout
 
             except socket.error as ex:
-                self.close()
+                await self.close()
                 self.logger.error(ex)
                 self.sock = self.create_socket(None)
                 self.on_blocking()
@@ -179,6 +179,24 @@ class Gsof(BaseProtocol):
                 self.on_blocking()
                 self.logger.error(f"Levantando error a ...Clliente {idc} Station ID: {ids}")
                 raise ex
+            except asyncio.IncompleteReadError as ir:
+                print(
+                    f"Error por lectura incomplete al leer {n} bytes en {self.station}")
+                self.logger.exception(
+                    f"""Station {self.station}, lectura incomplete al leer
+                    en readbytes, error: {ir}""")
+                raise ir
+            except asyncio.TimeoutError as te:
+                print(f"Error Timeout al leer {n} bytes en {self.station}")
+                self.logger.exception(
+                    f"Station {self.station}, Tiempo fuera al leer en readbytes, {te}")
+                raise te
+            except asyncio.IncompleteReadError as ir:
+                print(f"Incomplete read, station {self.station}")
+                self.logger.exception(
+                    f"Station {self.station}, Tiempo fuera al no poder leer en readbytes {n} bytes, {ir}")
+                raise ir
+
         msg["HEADER"] = self.msg_dict
         done = self.checksum
         return done, msg
