@@ -9,8 +9,10 @@ import time
 from networktools.ip import validURL
 from networktools.time import gps_time, now
 from rich import print
+from pyinstrument import Profiler
 
 async def run_test(loop, code, host, port, limit=2000, show=True):
+    #with Profiler(async_mode='enabled') as p:
     ginput = dict(host=host,
                   port=port,
                   code=code,
@@ -35,11 +37,15 @@ async def run_test(loop, code, host, port, limit=2000, show=True):
                 if heartbeat:
                     await gsof.get_message_header(idc)
                     done, msg = await gsof.get_records()
-                    ts = time.time()
                     if done:
                         if "TIME" in msg:
-                            ts_gsof = gps_time(msg)
-                            delta = ts - ts_gsof.timestamp()
+                            ts_gsof, source = gps_time(msg)
+                            print("TS GSOF", ts_gsof)
+                            ts = now()
+                            delta = ts.timestamp() - ts_gsof.timestamp()
+                            print(msg["TIME"])
+                            ts_gsof, source = gps_time(msg)
+                            delta = (ts - ts_gsof).total_seconds()
                             msg["DELTA_TIME"] = delta
                             print(f"Delta => {delta}")
                         if show:
@@ -53,7 +59,7 @@ async def run_test(loop, code, host, port, limit=2000, show=True):
             except Exception as ex:
                 gsof_file.write("]")
                 await gsof.close(idc)
-                print("Error %s" % ex)
+                print(f"Error {ex}")
                 loop.close()
                 raise ex
             except KeyboardInterrupt as ke:
@@ -64,6 +70,9 @@ async def run_test(loop, code, host, port, limit=2000, show=True):
                 raise ke
             counter += 1
         gsof_file.write("]")
+    # print("Profiling async")
+    # p.print()
+    # p.open_in_browser(timeline=True)
     await gsof.close(idc)
 
 
